From c644ac8f58895b9e29e9cfca79465fd2c0efaa5a Mon Sep 17 00:00:00 2001
From: 游雁 <zhifu.gzf@alibaba-inc.com>
Date: 星期二, 21 十一月 2023 14:09:01 +0800
Subject: [PATCH] funasr v2 setup

---
 funasr/fileio/sound_scp.py |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/funasr/fileio/sound_scp.py b/funasr/fileio/sound_scp.py
index b912f1e..b9364c6 100644
--- a/funasr/fileio/sound_scp.py
+++ b/funasr/fileio/sound_scp.py
@@ -4,7 +4,7 @@
 
 import random
 import numpy as np
-import soundfile
+import librosa
 import librosa
 
 import torch
@@ -116,7 +116,7 @@
     def __getitem__(self, key):
         wav = self.data[key]
         if self.normalize:
             # soundfile.read normalizes data to [-1,1] if dtype is not given
             array, rate = librosa.load(
                 wav, sr=self.dest_sample_rate, mono=self.always_2d
             )
@@ -116,7 +116,7 @@
         wav = self.data[key]
         if self.normalize:
-            # soundfile.read normalizes data to [-1,1] if dtype is not given
+            # librosa.load normalizes data to [-1,1] if dtype is not given
             array, rate = librosa.load(
                 wav, sr=self.dest_sample_rate, mono=self.always_2d

--
Gitblit v1.9.1